@@ -1,9 +1,9 @@
 from django_codemod.constants import DJANGO_3_0, DJANGO_4_0
-from django_codemod.visitors.base import BaseSimpleFuncRenameTransformer
+from django_codemod.visitors.base import BaseFuncRenameTransformer
 
 
-class HttpUrlQuoteTransformer(BaseSimpleFuncRenameTransformer):
-    """Resolve deprecation of ``django.utils.http.urlquote``."""
+class HttpUrlQuoteTransformer(BaseFuncRenameTransformer):
+    """Replace `django.utils.http.urlquote` by `urllib.parse.quote`."""
 
     deprecated_in = DJANGO_3_0
     removed_in = DJANGO_4_0
@@ -11,8 +11,8 @@ class HttpUrlQuoteTransformer(BaseSimpleFuncRenameTransformer):
     rename_to = "urllib.parse.quote"
 
 
-class HttpUrlQuotePlusTransformer(BaseSimpleFuncRenameTransformer):
-    """Resolve deprecation of ``django.utils.http.urlquote_plus``."""
+class HttpUrlQuotePlusTransformer(BaseFuncRenameTransformer):
+    """Replace `django.utils.http.urlquote_plus` by `urllib.parse.quote_plus`."""
 
     deprecated_in = DJANGO_3_0
     removed_in = DJANGO_4_0
@@ -20,8 +20,8 @@ class HttpUrlQuotePlusTransformer(BaseSimpleFuncRenameTransformer):
     rename_to = "urllib.parse.quote_plus"
 
 
-class HttpUrlUnQuoteTransformer(BaseSimpleFuncRenameTransformer):
-    """Resolve deprecation of ``django.utils.http.urlunquote``."""
+class HttpUrlUnQuoteTransformer(BaseFuncRenameTransformer):
+    """Replace `django.utils.http.urlunquote` by `urllib.parse.unquote`."""
 
     deprecated_in = DJANGO_3_0
     removed_in = DJANGO_4_0
@@ -29,8 +29,8 @@ class HttpUrlUnQuoteTransformer(BaseSimpleFuncRenameTransformer):
     rename_to = "urllib.parse.unquote"
 
 
-class HttpUrlUnQuotePlusTransformer(BaseSimpleFuncRenameTransformer):
-    """Resolve deprecation of ``django.utils.http.urlunquote_plus``."""
+class HttpUrlUnQuotePlusTransformer(BaseFuncRenameTransformer):
+    """Replace `django.utils.http.urlunquote_plus` by `urllib.parse.unquote_plus`."""
 
     deprecated_in = DJANGO_3_0
     removed_in = DJANGO_4_0
@@ -38,8 +38,8 @@ class HttpUrlUnQuotePlusTransformer(BaseSimpleFuncRenameTransformer):
     rename_to = "urllib.parse.unquote_plus"
 
 
-class IsSafeUrlTransformer(BaseSimpleFuncRenameTransformer):
-    """Resolve deprecation of ``django.utils.http.is_safe_url``."""
+class IsSafeUrlTransformer(BaseFuncRenameTransformer):
+    """Rename `django.utils.http.is_safe_url` to `url_has_allowed_host_and_scheme`."""
 
     deprecated_in = DJANGO_3_0
     removed_in = DJANGO_4_0
